# -*- coding: utf-8 -*-


class PayoutStatus:
    """
    Constants representing payout statuses. Available values are:
    """
    PENDING = 'pending'
    SUCCEEDED = 'succeeded'
    CANCELED = 'canceled'
