# -*- coding: utf-8 -*-
"""Top-level package for YooKassa API Python Client Library."""

from yookassa.domain.exceptions.api_error import ApiError
from yookassa.domain.exceptions.authorize_error import AuthorizeError
from yookassa.domain.exceptions.bad_request_error import BadRequestError
from yookassa.domain.exceptions.forbidden_error import ForbiddenError
from yookassa.domain.exceptions.not_found_error import NotFoundError
from yookassa.domain.exceptions.response_processing_error import ResponseProcessingError
from yookassa.domain.exceptions.too_many_request_error import TooManyRequestsError
from yookassa.domain.exceptions.unauthorized_error import UnauthorizedError
